@@ -1,5 +1,5 @@
-from metagen.generator import Generator
+from metagen.main import Generator
 from metagen.metadata import Application, Configuration, Scope, Place, Period, LayerTemplate, Attribute, SpatialWMS, \
     RelationSpatial, SpatialAttribute, SpatialWMTS, SpatialVector, Style, Case, RelationAttribute, Tag
 
-__version__ = '1.1.8'
\ No newline at end of file
+__version__ = '1.1.10'
\ No newline at end of file
